package com.jjt.ws.service;

import com.jjt.elec.domain.ElecPrice;
import com.jjt.ws.domain.TwinRzCalcMonth;
import com.jjt.ws.domain.TwinWorkshopCalc;

import java.util.Date;
import java.util.List;

/**
 * 染整月统计Service接口
 *
 * @author wukai
 * @date 2025-04-23
 */
public interface ITwinRzCalcMonthService {
    /**
     * 查询染整月统计
     *
     * @param calcId 染整月统计主键
     * @return 染整月统计
     */
    public TwinRzCalcMonth selectTwinRzCalcMonthByCalcId(Long calcId);

    /**
     * 查询染整月统计列表
     *
     * @param twinRzCalcMonth 染整月统计
     * @return 染整月统计集合
     */
    public List<TwinRzCalcMonth> selectTwinRzCalcMonthList(TwinRzCalcMonth twinRzCalcMonth);

    /**
     * 新增染整月统计
     *
     * @param twinRzCalcMonth 染整月统计
     * @return 结果
     */
    public int insertTwinRzCalcMonth(TwinRzCalcMonth twinRzCalcMonth);

    /**
     * 修改染整月统计
     *
     * @param twinRzCalcMonth 染整月统计
     * @return 结果
     */
    public int updateTwinRzCalcMonth(TwinRzCalcMonth twinRzCalcMonth);

    /**
     * 批量删除染整月统计
     *
     * @param calcIds 需要删除的染整月统计主键集合
     * @return 结果
     */
    public int deleteTwinRzCalcMonthByCalcIds(Long[] calcIds);

    /**
     * 删除染整月统计信息
     *
     * @param calcId 染整月统计主键
     * @return 结果
     */
    public int deleteTwinRzCalcMonthByCalcId(Long calcId);

    /**
     * 染整线月统计
     *
     * @param date      时间
     * @param calcList  统计数据
     */
    void calc(Date date, List<TwinWorkshopCalc> calcList);
}
